import {
  db, Model, Draft, WikidotUser, WikidotPage, Branch,
} from '../models';

import repl = require('repl');

export default async function runConsole(): Promise<void> {
  process.env.REPL_MODE = '1';

  await db.ready();

  let knex;
  try {
    knex = db.primary;
  } catch {
    console.log('No master available, trying to start in read-only mode');
    knex = db.replica;
  }
  if (!knex) {
    console.error('No connections available, exiting');
  }

  Model.knex(knex);

  const replServer = repl.start();

  replServer.context.r = (p: Promise<any>) => {
    p.then(result => console.log('\n\n', result, '\n\nPress enter to continue')).catch(console.error);
  };
  replServer.context.s = (p: Promise<any>) => {
    p.then(() => console.log('\n\nDone', '\n\nPress enter to continue')).catch(console.error);
  };

  replServer.context.Model = Model;
  replServer.context.WikidotUser = WikidotUser;
  replServer.context.WikidotPage = WikidotPage;
  replServer.context.Branch = Branch;
  replServer.context.Draft = Draft;
}
