import { Request, Response } from 'express';
import { db, Draft } from '../../models';

export default async (req: Request, res: Response) => {
  const id = Draft.ID_REG.test(req.params.id) && req.params.id;
  if (!id) {
    res.status(400).send({ error: 'Missing or incorrect draft id' });
    return;
  }

  const { title, content } = req.body;
  if (!title || !content) {
    res.status(400).send({ error: 'Missing title or content' });
  }

  const result = await Draft.query(db.primary)
    .where({ id })
    .first()
    .update({
      title,
      content,
      updatedAt: new Date(),
    })
    .returning('updated_at');

  if (result) {
    res.send(result);
  } else {
    res.status(404).send({ error: 'Draft not found' });
  }
};
