import { Request, Response } from 'express';
import { reportError } from '../../../core/utils';
import { db } from '../../../models';

export default async (req: Request, res: Response) => {
  const { wiki } = req.query;

  try {
    if (!wiki) {
      res.status(400).send('Wiki name is required');
      return;
    }
    const result = await db.replica.raw(`
      SELECT DISTINCT unnest(tags) AS tag
      FROM wikidot_pages
      WHERE wiki_name = ?;`, [wiki]);
    const tags = result.rows.map((row: { tag: string }) => row.tag);
    res.send(tags.sort((one: string, another: string) => one.localeCompare(another)));
  } catch (error) {
    res.status(500).send('Unhandled internal error, incident reported');
    reportError(error, { tags: { location: 'wikidot/tags-list' } });
  }
};
