import * as Consumer from 'sqs-consumer';
import { Queues, QueuesUrls } from '../components/queues';
import { log, reportError } from './utils';

import path = require('path');

const runnerPath = path.resolve(__dirname, '../', 'components/task-runner.js');

export interface AppTask {
  task: string;
  args: any;
}

const TASK_NAME_REG = /^[a-zA-Z0-9-]+$/;

function taskRunner(job: AppTask): Promise<any> {
  const taskName = job.task;
  if (!TASK_NAME_REG.test(taskName)) {
    throw new Error(`Incorrect task name "${taskName}"`);
  }
  const taskPath = path.resolve(__dirname, '../', 'tasks', taskName);
  return require(taskPath).default(...job.args);
}

export default function runWorker(): void {
  log('Initiating worker master process');

  Object.keys(QueuesUrls).forEach((queueName: string) => {
    const queueUrl = QueuesUrls[queueName];

    const consumer = Consumer.create({
      queueUrl,
      handleMessage: (message, done) => {
        const { task, args } = JSON.parse(message.Body as string);
        taskRunner({ task, args })
          .then(() => {
            done();
          })
          .catch((error) => {
            reportError(error, {
              message: 'Error during task processing',
              extra: {
                task,
                args,
              },
            });
            done(error);
          });
      },
      batchSize: 4,
    });

    consumer.on('error', (error) => {
      reportError(error, {
        message: 'Error during task processing',
        extra: {
          queueName,
        },
      });
    });

    consumer.start();
    log('Initiated worker for queue', { queueName });
  });
}
