'use strict';

exports.up = knex => knex.raw(`
  CREATE SEQUENCE counter_seq;

  CREATE OR REPLACE FUNCTION get_id(OUT result bigint) AS $$
  DECLARE
    our_epoch bigint := 1514754000000;
    seq_id bigint;
    now_millis bigint;
    shard_id int := 1;
  BEGIN
    SELECT nextval('counter_seq') % 4096 INTO seq_id;

    SELECT FLOOR(EXTRACT(EPOCH FROM clock_timestamp()) * 1000) INTO now_millis;
    result := (now_millis - our_epoch) << 23;
    result := result | (shard_id << 10);
    result := result | (seq_id);
  END;
  $$ LANGUAGE PLPGSQL;

  CREATE TABLE public.drafts
  (
    id         BIGINT    NOT NULL PRIMARY KEY DEFAULT get_id(),
    title      TEXT      NOT NULL             DEFAULT '',
    content    TEXT      NOT NULL             DEFAULT '',
    created_at TIMESTAMP NOT NULL             DEFAULT NOW(),
    updated_at TIMESTAMP NOT NULL             DEFAULT NOW()
  );
`);

exports.down = knex => knex.raw(`
  DROP TABLE drafts;
  DROP FUNCTION get_id;
`);
