import {
  Model as BaseModel, knexSnakeCaseMappers, raw, ValidationError,
} from 'objection';
import { PGDispatcher } from '../components/pg-dispatcher';
import { log, reportError } from '../core/utils';

export const db = new PGDispatcher({
  connections: (process.env.POSTGRES_DSN_LIST as string).split(','),
  options: {
    healthcheckInterval: 5000,
    healthcheckTimeout: 700,
  },
  knexOptions: {
    ...knexSnakeCaseMappers(),
  },
  logger: {
    info: ({ message, data }) => {
      if (!process.env.REPL_MODE) {
        log(message, data);
      }
    },
    error: ({ message, error, data }) => {
      const messageToReport = message || 'Error without description';
      const errorToReport = error || new Error(messageToReport);
      reportError(errorToReport, {
        message: messageToReport,
        extra: data || {},
      });
    },
  },
});

export class Model extends BaseModel {
  static get primary() {
    return db.primary;
  }

  get primary() { // eslint-disable-line class-methods-use-this
    return db.primary;
  }

  static get replica() {
    return db.replica;
  }

  get replica() { // eslint-disable-line class-methods-use-this
    return db.replica;
  }
}

export { ValidationError } from 'objection';

export { default as WikidotUser } from './wikidot-user';
export { default as WikidotPage } from './wikidot-page';
export { default as Branch } from './branch';
export { default as Draft } from './draft';
