import { GuildMember } from 'discord.js';
import { logImportant, reportError } from '../core/utils';

import Discord = require('discord.js');

const { WikidotUser, db } = require('../models');

const discord = new Discord.Client();
const token = process.env.DISCORD_BOT_TOKEN;

const SCP_RU_GUILD_ID = '106464299056128000';
const MEMBERS_ROLE_ID = '106465861476319232';

export default function run(): Promise<void> {
  return new Promise((resolve) => {
    discord.on('ready', () => {
      const guild = discord.guilds.find((data, key) => key === SCP_RU_GUILD_ID);
      const memberRole = guild.roles.find(role => role.id === MEMBERS_ROLE_ID);

      logImportant('Initiating Discord roles sync');

      let numberOfMembersToSync: number;
      WikidotUser.membersWithDiscordTag()
        .then((memberDiscordIDs: string[]) => {
          const usersToUpdate = guild.members.filterArray((member) => {
            const { user } = member;
            const userId = `${user.username}#${user.discriminator}`;
            return memberDiscordIDs.includes(userId) && !member.roles.has(MEMBERS_ROLE_ID);
          });
          numberOfMembersToSync = usersToUpdate.length;
          if (numberOfMembersToSync) {
            logImportant(`Adding roles: ${numberOfMembersToSync}`);
          } else {
            logImportant('Everything is in sync');
          }
          return usersToUpdate;
        })
        .map((userToUpdate: GuildMember) => {
          logImportant(`Adding role to user \`${userToUpdate.user.username}\``);
          return userToUpdate.addRole(memberRole);
        })
        .then(() => {
          if (numberOfMembersToSync) {
            logImportant(`Synced discord roles for ${numberOfMembersToSync} user(s)`);
          }
          resolve();
        })
        .catch((error: Error) => {
          reportError(error, { message: 'Error setting discord member roles' });
          resolve();
        });
    });
    discord.login(token);
  });
}
