import { SITES, WikidotKit } from '../components/wikidot-kit';
import { log, reportError } from '../core/utils';
import { WikidotUser } from '../models';

export default async function run(siteName: string, uid: number): Promise<void> {
  const wiki = SITES[siteName];
  log(`Importing member ${uid} from ${wiki.name}`);

  try {
    const user = await WikidotKit.fetchUserProfile(wiki.url, uid);
    log('Imported user profile', user);

    await WikidotUser.upsert({
      uid: user.uid,
      username: user.username,
      regDate: user.userSince,
      about: user.about,
      memberships: { [siteName]: user.memberSince },
    });
  } catch (error) {
    reportError(error, { message: 'Error importing member profile', extra: { uid } });
  }
}
