import { logImportant, reportError, batchedEnqueue } from '../core/utils';
import { wk, SITES, WikidotKit } from '../components/wikidot-kit';

export default async function run(siteName: string): Promise<void> {
  if (!siteName) {
    throw new Error('Site name should be specified');
  }
  const wiki = SITES[siteName];

  logImportant(`Initiating \`${siteName}\` members import`);
  try {
    const membersList = await WikidotKit.fetchMembersList(wiki.url);

    const tasks = membersList.map(user => ({
      task: 'member-import',
      args: [siteName, user.uid],
    }));

    await batchedEnqueue(tasks, 'import');
  } catch (error) {
    reportError(error, { message: 'Error importing members list' });
  }
}
