import { db, WikidotPage } from '../models';
import { log, reportError } from '../core/utils';

import cheerio = require('cheerio');
import Bluebird = require('bluebird');

const OBJECT_TITLE_REGEXP = /^SCP/;

export default async function run(): Promise<void> {
  log('Performing EN object titles extraction');

  try {
    const wikiName = 'scp-wiki';
    const pageNames = [
      'scp-series',
      'scp-series-2',
      'scp-series-3',
      'scp-series-4',
      'joke-scps',
      'archived-scps',
      'scp-ex',
    ];

    const listPages = await WikidotPage
      .query(db.replica)
      .select('html')
      .where({ wikiName })
      .where('name', 'in', pageNames);

    const html = listPages.reduce((result: string, page: WikidotPage) => result + page.html, '');

    const $ = cheerio.load(html);

    interface TitledObject {
      name: string;
      title: string;
    }

    const titledObjects = Array.from($('li')).reduce((objects: TitledObject[], line) => {
      const text = $(line).text();
      if (OBJECT_TITLE_REGEXP.test(text)) {
        objects.push({
          name: text.split(' - ')[0].toLowerCase(),
          title: text,
        });
      }
      return objects;
    }, []);

    await Bluebird.map(titledObjects, async (object) => {
      await WikidotPage
        .query(db.primary)
        .patch({ title: object.title })
        .where({ wikiName, name: object.name });
    }, { concurrency: 10 });
  } catch (error) {
    reportError(error, { message: 'Error extraction object titles' });
  }
}
