"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Consumer = require("sqs-consumer");
const queues_1 = require("../components/queues");
const utils_1 = require("./utils");
const path = require("path");
const runnerPath = path.resolve(__dirname, '../', 'components/task-runner.js');
const TASK_NAME_REG = /^[a-zA-Z0-9-]+$/;
function taskRunner(job) {
    const taskName = job.task;
    if (!TASK_NAME_REG.test(taskName)) {
        throw new Error(`Incorrect task name "${taskName}"`);
    }
    const taskPath = path.resolve(__dirname, '../', 'tasks', taskName);
    return require(taskPath).default(...job.args);
}
function runWorker() {
    utils_1.log('Initiating worker master process');
    Object.keys(queues_1.QueuesUrls).forEach((queueName) => {
        const queueUrl = queues_1.QueuesUrls[queueName];
        const consumer = Consumer.create({
            queueUrl,
            handleMessage: (message, done) => {
                const { task, args } = JSON.parse(message.Body);
                taskRunner({ task, args })
                    .then(() => {
                    done();
                })
                    .catch((error) => {
                    utils_1.reportError(error, {
                        message: 'Error during task processing',
                        extra: {
                            task,
                            args,
                        },
                    });
                    done(error);
                });
            },
            batchSize: 4,
        });
        consumer.on('error', (error) => {
            utils_1.reportError(error, {
                message: 'Error during task processing',
                extra: {
                    queueName,
                },
            });
        });
        consumer.start();
        utils_1.log('Initiated worker for queue', { queueName });
    });
}
exports.default = runWorker;
//# sourceMappingURL=worker.js.map