"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const objection_1 = require("objection");
const pg_dispatcher_1 = require("../components/pg-dispatcher");
const utils_1 = require("../core/utils");
exports.db = new pg_dispatcher_1.PGDispatcher({
    connections: process.env.POSTGRES_DSN_LIST.split(','),
    options: {
        healthcheckInterval: 5000,
        healthcheckTimeout: 700,
    },
    knexOptions: Object.assign({}, objection_1.knexSnakeCaseMappers()),
    logger: {
        info: ({ message, data }) => {
            if (!process.env.REPL_MODE) {
                utils_1.log(message, data);
            }
        },
        error: ({ message, error, data }) => {
            const messageToReport = message || 'Error without description';
            const errorToReport = error || new Error(messageToReport);
            utils_1.reportError(errorToReport, {
                message: messageToReport,
                extra: data || {},
            });
        },
    },
});
class Model extends objection_1.Model {
    static get primary() {
        return exports.db.primary;
    }
    get primary() {
        return exports.db.primary;
    }
    static get replica() {
        return exports.db.replica;
    }
    get replica() {
        return exports.db.replica;
    }
}
exports.Model = Model;
var objection_2 = require("objection");
exports.ValidationError = objection_2.ValidationError;
var wikidot_user_1 = require("./wikidot-user");
exports.WikidotUser = wikidot_user_1.default;
var wikidot_page_1 = require("./wikidot-page");
exports.WikidotPage = wikidot_page_1.default;
var branch_1 = require("./branch");
exports.Branch = branch_1.default;
var draft_1 = require("./draft");
exports.Draft = draft_1.default;
//# sourceMappingURL=index.js.map