"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const objection_1 = require("objection");
const routes = [
    {
        name: 'main',
        path: '/',
    },
    {
        name: 'ping',
        path: '/ping',
    },
    {
        name: 'wikidot/random-page',
        path: '/wikidot_random_page',
    },
    {
        name: 'wikidot/api/random-page',
        path: '/api/random_page',
    },
    {
        name: 'wikidot/api/random-page',
        path: '/api/wikidot_random_page',
    },
    {
        name: 'wikidot/api/tags-list',
        path: '/_api/wikidot_tags_search/list',
    },
    {
        name: 'wikidot/api/tags-search',
        path: '/_api/wikidot_tags_search/find',
    },
    {
        name: 'wikidot/get-page',
        path: '/api/wikidot/pages/:wikiName/:pageName',
    },
    {
        name: 'drafts/list',
        path: '/api/private/drafts',
    },
    {
        name: 'drafts/show',
        path: '/api/private/drafts/:id',
    },
    {
        name: 'drafts/create',
        path: '/api/private/drafts',
        method: 'post',
    },
    {
        name: 'drafts/update',
        path: '/api/private/drafts/:id',
        method: 'post',
    },
    {
        name: 'drafts/delete',
        path: '/api/private/drafts/:id',
        method: 'delete',
    },
];
function initRoutes(app) {
    routes.forEach((route) => {
        const method = route.method || 'get';
        const routeMiddleware = [];
        const routeHandler = require(`./controllers/${route.name}`).default;
        app[method](route.path, routeMiddleware, (req, res, next) => {
            Promise
                .resolve(routeHandler(req, res))
                .catch((error) => {
                if (error instanceof objection_1.ValidationError) {
                    return res.status(400).send({ error: 'Validation error', details: error.data });
                }
                return next(error);
            });
        });
    });
}
exports.default = initRoutes;
//# sourceMappingURL=routes.js.map