"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../models");
const utils_1 = require("../core/utils");
const cheerio = require("cheerio");
const Bluebird = require("bluebird");
const OBJECT_TITLE_REGEXP = /^SCP/;
async function run() {
    utils_1.log('Performing EN object titles extraction');
    try {
        const wikiName = 'scp-wiki';
        const pageNames = [
            'scp-series',
            'scp-series-2',
            'scp-series-3',
            'scp-series-4',
            'joke-scps',
            'archived-scps',
            'scp-ex',
        ];
        const listPages = await models_1.WikidotPage
            .query(models_1.db.replica)
            .select('html')
            .where({ wikiName })
            .where('name', 'in', pageNames);
        const html = listPages.reduce((result, page) => result + page.html, '');
        const $ = cheerio.load(html);
        const titledObjects = Array.from($('li')).reduce((objects, line) => {
            const text = $(line).text();
            if (OBJECT_TITLE_REGEXP.test(text)) {
                objects.push({
                    name: text.split(' - ')[0].toLowerCase(),
                    title: text,
                });
            }
            return objects;
        }, []);
        await Bluebird.map(titledObjects, async (object) => {
            await models_1.WikidotPage
                .query(models_1.db.primary)
                .patch({ title: object.title })
                .where({ wikiName, name: object.name });
        }, { concurrency: 10 });
    }
    catch (error) {
        utils_1.reportError(error, { message: 'Error extraction object titles' });
    }
}
exports.default = run;
//# sourceMappingURL=object-titles-extraction.js.map