"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../models");
const utils_1 = require("../core/utils");
const wikidot_kit_1 = require("../components/wikidot-kit");
async function run() {
    utils_1.log('Performing pages lists import');
    const branches = await models_1.Branch.query(models_1.db.replica);
    await Promise.all(branches.map(async (branch) => {
        const { name } = branch;
        try {
            const pagesList = await wikidot_kit_1.wk.fetchPagesList(name);
            await models_1.Branch
                .query(models_1.db.primary)
                .patch({ pagesList })
                .where({ name });
            utils_1.log(`Pages list for wiki ${name} updated`);
        }
        catch (error) {
            utils_1.reportError(error, {
                message: 'Error during pages list update',
                extra: { name },
            });
        }
    }));
    utils_1.log('Pages list for all wikis updated');
}
exports.default = run;
//# sourceMappingURL=pages-lists-import.js.map